@@ -3,7 +3,7 @@
 #Jarrod Hadfield in the 
 #MCMCglmm package
 ######################################
-sm2list<-function (A = NULL, rownames = NULL, colnames=c("row", "column", "A"))
+sm2list<-function(A, rownames = NULL, colnames=c("row", "column", "A"))
 {
     ginv <- data.frame(Row = rep(1:length(A@p[-1]),
         diff(A@p)), Column = A@i + 1, Ainverse = A@x)
